@@ -1,7 +1,11 @@
+from warnings import warn
+
 try:
     import pydantic  # type: ignore
-except ImportError:
-    raise ImportError("camel-converter must be installed with the pydantic extra to use this class")
+except ImportError as e:
+    raise ImportError(
+        "camel-converter must be installed with the pydantic extra to use this class"
+    ) from e
 
 from camel_converter import to_camel
 
@@ -19,6 +23,12 @@ class CamelBase(pydantic.BaseModel):
         if int(pydantic.__version__[:1]) >= 2:  # type: ignore[attr-defined]
             model_config = pydantic.ConfigDict(alias_generator=to_camel, populate_by_name=True)  # type: ignore[attr-defined]
         else:  # pragma: no cover
+            warn(
+                "The use of Pydantic less than version 2 is depreciated and will be removed in a future release",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+
             # Raise an AttributeError to match the AttributeError on __version__ because in either
             # case we need to get to the same place.
             raise AttributeError
